"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PowerShell = exports.PSExecutableType = void 0;
const os_1 = require("os");
const is_wsl_1 = __importDefault(require("is-wsl"));
const child_shell_1 = require("child-shell");
const PSCommand_1 = require("./PSCommand");
var PSExecutableType;
(function (PSExecutableType) {
    PSExecutableType["PowerShell"] = "powershell";
    PSExecutableType["PowerShellCore"] = "pwsh";
    PSExecutableType["PowerShellCorePreview"] = "pwsh-preview";
})(PSExecutableType = exports.PSExecutableType || (exports.PSExecutableType = {}));
const isWin = os_1.platform() === 'win32' || is_wsl_1.default;
class PowerShell extends child_shell_1.Shell {
    constructor(psOptions = {}) {
        const options = psOptions;
        options.executableOptions = Object.assign(Object.assign({ '-NoLogo': true }, psOptions.executableOptions), { '-NoExit': true, '-Command': '-' });
        super(options, PSCommand_1.PSCommand);
    }
    setExecutable({ pwsh = false, pwshPrev = false, executable, }) {
        const { PowerShell, PowerShellCore, PowerShellCorePreview } = PSExecutableType;
        if (process.env.NPS) {
            return process.env.NPS;
        }
        if (pwsh) {
            return PowerShellCore;
        }
        if (pwshPrev) {
            return PowerShellCorePreview;
        }
        if (!executable) {
            return !isWin ? PowerShellCore : PowerShell;
        }
        switch (executable) {
            case PowerShell:
                return PowerShellCore;
            case PowerShellCore:
                return PowerShellCore;
            case PowerShellCorePreview:
                return PowerShellCore;
            default:
                throw new Error('Unable to determine PowerShell executable');
        }
    }
    writeToOutput(input) {
        return `[Console]::Out.WriteLine("${input}")`;
    }
    writeToError(input) {
        return `[Console]::Error.WriteLine("${input}")`;
    }
}
exports.PowerShell = PowerShell;
//# sourceMappingURL=PowerShell.js.map